==> manydhcp2.5.2.tar.bz2: manydhcp/ondisk/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['menu-btn19-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['ond_id'])) {puterror($result2['skin'],$TEXT['param_err7']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ond_id'])>12) {puterror($result2['skin'],$TEXT['param_err8']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ond_id'] = rep($_GET['ond_id']);

  //*************************************
  //Информация для лога
  $query = "SELECT * FROM `tbl_ondisk` WHERE `ond_id`='".$_GET['ond_id']."' ";
  $result = mysql_query($query);
  if (!$result) {puterror($result2['skin'],$TEXT['error-tbl9']); require_once "../utils/bottom_adm.php"; exit();}
      $result2 = mysql_fetch_array($result);

  //Вводим переменные
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-ondisk3'];
  $what = $TEXT['ondisk_fs']." &laquo;".$result2['disk_name']."&raquo;, ".$TEXT['log-id'].$_GET['ond_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_ondisk` WHERE `ond_id`='".$_GET['ond_id']."' LIMIT 1";
  if(mysql_query($query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl9']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/ondisk/delete.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['menu-btn19-title'];

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['ond_id'])) {puterror($result2['skin'],$TEXT['param_err7']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ond_id'])>12) {puterror($result2['skin'],$TEXT['param_err8']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ond_id'] = rep($_GET['ond_id']);

  //*************************************
  //Информация для лога
  $query = "SELECT * FROM `tbl_ondisk` WHERE `ond_id`='".$_GET['ond_id']."' ";
  $result = mysqli_query($dbcnx,$query);
  if(!$result) {puterror($result2['skin'],$TEXT['error-tbl9']); require_once "../utils/bottom_adm.php"; exit();}
    $result2 = mysqli_fetch_array($result,MYSQLI_ASSOC);

  //Вводим переменные
  $ip = $_SERVER['REMOTE_ADDR'];
  $doing = $TEXT['log-ondisk3'];
  $what = $TEXT['ondisk_fs']." &laquo;".$result2['disk_name']."&raquo;, ".$TEXT['log-id'].$_GET['ond_id'];
  $who = $result2['familiya']." ".$result2['name'];
  //*************************************

  $query = "DELETE FROM `tbl_ondisk` WHERE `ond_id`='".$_GET['ond_id']."' LIMIT 1";
  if(mysqli_query($dbcnx,$query))
  {
    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
             echo "<html><head>
                   <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php' />
                   </head></html>";
           } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl9']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>
